# Released under the MIT License. See LICENSE for details.
#
"""Exposed functionality not intended for full public use.

Classes and functions contained here, while technically 'public', may change
or disappear without warning, so should be avoided (or used sparingly and
defensively) in mods.
"""
from __future__ import annotations

from _ba import (
    show_online_score_ui,
    set_ui_input_device,
    is_party_icon_visible,
    getinputdevice,
    add_clean_frame_callback,
    unlock_all_input,
    increment_analytics_count,
    set_debug_speed_exponent,
    get_special_widget,
    get_qrcode_texture,
    get_string_height,
    get_string_width,
    show_app_invite,
    appnameupper,
    lock_all_input,
    open_file_externally,
    fade_screen,
    appname,
    have_incentivized_ad,
    has_video_ads,
    workspaces_in_use,
    set_party_icon_always_visible,
    connect_to_party,
    get_game_port,
    end_host_scanning,
    host_scan_cycle,
    charstr,
    get_public_party_enabled,
    get_public_party_max_size,
    set_public_party_name,
    set_public_party_max_size,
    set_authenticate_clients,
    set_public_party_enabled,
    reset_random_player_names,
    new_host_session,
    get_foreground_host_session,
    get_local_active_input_devices_count,
    get_ui_input_device,
    is_in_replay,
    set_replay_speed_exponent,
    get_replay_speed_exponent,
    disconnect_from_host,
    set_party_window_open,
    get_connection_to_host_info,
    get_chat_messages,
    get_game_roster,
    disconnect_client,
    chatmessage,
    get_random_names,
    have_permission,
    request_permission,
    have_touchscreen_input,
    is_xcode_build,
    set_low_level_config_value,
    get_low_level_config_value,
    capture_gamepad_input,
    release_gamepad_input,
    has_gamma_control,
    get_max_graphics_quality,
    get_display_resolution,
    capture_keyboard_input,
    release_keyboard_input,
    value_test,
    set_touchscreen_editing,
    is_running_on_fire_tv,
    android_get_external_files_dir,
    set_telnet_access_enabled,
    new_replay_session,
    get_replays_dir,
)

from ba._map import (
    get_map_class,
    register_map,
    preload_map_preview_media,
    get_map_display_string,
    get_filtered_map_name,
)
from ba._appconfig import commit_app_config
from ba._input import (
    get_device_value,
    get_input_map_hash,
    get_input_device_config,
)
from ba._general import getclass, json_prep, get_type_name
from ba._activitytypes import JoinActivity, ScoreScreenActivity
from ba._apputils import (
    is_browser_likely_available,
    get_remote_app_name,
    should_submit_debug_info,
)
from ba._benchmark import (
    run_gpu_benchmark,
    run_cpu_benchmark,
    run_media_reload_benchmark,
    run_stress_test,
)
from ba._campaign import getcampaign
from ba._messages import PlayerProfilesChangedMessage
from ba._multiteamsession import DEFAULT_TEAM_COLORS, DEFAULT_TEAM_NAMES
from ba._music import do_play_music
from ba._net import (
    master_server_get,
    master_server_post,
    get_ip_address_type,
    DEFAULT_REQUEST_TIMEOUT_SECONDS,
)
from ba._powerup import get_default_powerup_distribution
from ba._profile import (
    get_player_profile_colors,
    get_player_profile_icon,
    get_player_colors,
)
from ba._tips import get_next_tip
from ba._playlist import (
    get_default_free_for_all_playlist,
    get_default_teams_playlist,
    filter_playlist,
)
from ba._store import (
    get_available_sale_time,
    get_available_purchase_count,
    get_store_item_name_translated,
    get_store_item_display_size,
    get_store_layout,
    get_store_item,
    get_clean_price,
    get_unowned_maps,
    get_unowned_game_types,
)
from ba._tournament import get_tournament_prize_strings
from ba._gameutils import get_trophy_string

from ba._internal import (
    get_v2_fleet,
    get_master_server_address,
    is_blessed,
    get_news_show,
    game_service_has_leaderboard,
    report_achievement,
    submit_score,
    tournament_query,
    power_ranking_query,
    restore_purchases,
    purchase,
    get_purchases_state,
    get_purchased,
    get_price,
    in_game_purchase,
    add_transaction,
    reset_achievements,
    get_public_login_id,
    have_outstanding_transactions,
    run_transactions,
    get_v1_account_misc_read_val,
    get_v1_account_misc_read_val_2,
    get_v1_account_misc_val,
    get_v1_account_ticket_count,
    get_v1_account_state_num,
    get_v1_account_state,
    get_v1_account_display_string,
    get_v1_account_type,
    get_v1_account_name,
    sign_out_v1,
    sign_in_v1,
    mark_config_dirty,
)

__all__ = [
    'show_online_score_ui',
    'set_ui_input_device',
    'is_party_icon_visible',
    'getinputdevice',
    'add_clean_frame_callback',
    'unlock_all_input',
    'increment_analytics_count',
    'set_debug_speed_exponent',
    'get_special_widget',
    'get_qrcode_texture',
    'get_string_height',
    'get_string_width',
    'show_app_invite',
    'appnameupper',
    'lock_all_input',
    'open_file_externally',
    'fade_screen',
    'appname',
    'have_incentivized_ad',
    'has_video_ads',
    'workspaces_in_use',
    'set_party_icon_always_visible',
    'connect_to_party',
    'get_game_port',
    'end_host_scanning',
    'host_scan_cycle',
    'charstr',
    'get_public_party_enabled',
    'get_public_party_max_size',
    'set_public_party_name',
    'set_public_party_max_size',
    'set_authenticate_clients',
    'set_public_party_enabled',
    'reset_random_player_names',
    'new_host_session',
    'get_foreground_host_session',
    'get_local_active_input_devices_count',
    'get_ui_input_device',
    'is_in_replay',
    'set_replay_speed_exponent',
    'get_replay_speed_exponent',
    'disconnect_from_host',
    'set_party_window_open',
    'get_connection_to_host_info',
    'get_chat_messages',
    'get_game_roster',
    'disconnect_client',
    'chatmessage',
    'get_random_names',
    'have_permission',
    'request_permission',
    'have_touchscreen_input',
    'is_xcode_build',
    'set_low_level_config_value',
    'get_low_level_config_value',
    'capture_gamepad_input',
    'release_gamepad_input',
    'has_gamma_control',
    'get_max_graphics_quality',
    'get_display_resolution',
    'capture_keyboard_input',
    'release_keyboard_input',
    'value_test',
    'set_touchscreen_editing',
    'is_running_on_fire_tv',
    'android_get_external_files_dir',
    'set_telnet_access_enabled',
    'new_replay_session',
    'get_replays_dir',
    # DIVIDER
    'get_unowned_maps',
    'get_unowned_game_types',
    'get_map_class',
    'register_map',
    'preload_map_preview_media',
    'get_map_display_string',
    'get_filtered_map_name',
    'commit_app_config',
    'get_device_value',
    'get_input_map_hash',
    'get_input_device_config',
    'getclass',
    'json_prep',
    'get_type_name',
    'JoinActivity',
    'ScoreScreenActivity',
    'is_browser_likely_available',
    'get_remote_app_name',
    'should_submit_debug_info',
    'run_gpu_benchmark',
    'run_cpu_benchmark',
    'run_media_reload_benchmark',
    'run_stress_test',
    'getcampaign',
    'PlayerProfilesChangedMessage',
    'DEFAULT_TEAM_COLORS',
    'DEFAULT_TEAM_NAMES',
    'do_play_music',
    'master_server_get',
    'master_server_post',
    'get_ip_address_type',
    'DEFAULT_REQUEST_TIMEOUT_SECONDS',
    'get_default_powerup_distribution',
    'get_player_profile_colors',
    'get_player_profile_icon',
    'get_player_colors',
    'get_next_tip',
    'get_default_free_for_all_playlist',
    'get_default_teams_playlist',
    'filter_playlist',
    'get_available_sale_time',
    'get_available_purchase_count',
    'get_store_item_name_translated',
    'get_store_item_display_size',
    'get_store_layout',
    'get_store_item',
    'get_clean_price',
    'get_tournament_prize_strings',
    'get_trophy_string',
    'get_v2_fleet',
    'get_master_server_address',
    'is_blessed',
    'get_news_show',
    'game_service_has_leaderboard',
    'report_achievement',
    'submit_score',
    'tournament_query',
    'power_ranking_query',
    'restore_purchases',
    'purchase',
    'get_purchases_state',
    'get_purchased',
    'get_price',
    'in_game_purchase',
    'add_transaction',
    'reset_achievements',
    'get_public_login_id',
    'have_outstanding_transactions',
    'run_transactions',
    'get_v1_account_misc_read_val',
    'get_v1_account_misc_read_val_2',
    'get_v1_account_misc_val',
    'get_v1_account_ticket_count',
    'get_v1_account_state_num',
    'get_v1_account_state',
    'get_v1_account_display_string',
    'get_v1_account_type',
    'get_v1_account_name',
    'sign_out_v1',
    'sign_in_v1',
    'mark_config_dirty',
]
